import type { GetServerSideProps } from 'next'
import type { FetchResult } from '../types'
import { ResponseStatus } from '../types'

import Image from 'next/image'
import Link from 'next/link'
import { Layout } from '@vercel/examples-ui'

import api from '../api'
import NotFoundPage from './404'


interface Props {
  fetchResult: FetchResult
}


export const getServerSideProps: GetServerSideProps = async ({ req }) => {
  const fetchResult = await api.fetch();
  return {
    props: {
      fetchResult,
    },
  }
}

function SSRProductPage({ fetchResult }: Props) {
  if (fetchResult.status !== ResponseStatus.sucess) {
    return (
      <>
        <NotFoundPage />
      </>
    )
  }

  return (
    <>
      <div className='flex-1 max-w-full'>
        <div className="flex -mb-40 lg:-mb-56 col-auto columns-1 gap-1 justify-center flex-wrap basis-1 flex-auto size-auto">
          {fetchResult.data.map((a, index) => (
            <Link key={index} href={a.description.replace(/\s/g, '')}>
              <Image
                key={index}
                className="my-6 size-auto object-contain"
                alt={a.description}
                src={a.link}
                placeholder={"blur"}
                height={a.height}
                width={a.width}
                priority={index < 2}
              />
            </Link>

          ))}
        </div>
      </div>
    </>
  )

}


SSRProductPage.Layout = Layout

export default SSRProductPage
